@@ -674,7 +674,7 @@ function api_google_get_client($profile, $app_name, $json_oauth, $auth_code = ''
         }catch(Exception $e){
             return false;
         }
-    
+
     }
     file_put_contents($json_file, $json_oauth);
     include_once($prod_path . "/third/oauth/google-api-php-client/vendor/autoload.php");
@@ -1518,13 +1518,16 @@ function sc_api_storage_delete($arr_settings)
                         $_id = " AND parents='" . $id . "'";
                     }
 
-                    $results = $instance->files->listFiles(['q' => 'name="' . utf8_encode($arr_settings['file_name']) . '" AND trashed = false ' . $_id])->getFiles();
+/*--- Scriptcase - PHP 8.2 ---*/
+/*                    $results = $instance->files->listFiles(['q' => 'name="' . utf8_encode($arr_settings['file_name']) . '" AND trashed = false ' . $_id])->getFiles(); */
+                    $results = $instance->files->listFiles(['q' => 'name="' . mb_convert_encoding($arr_settings['file_name'], 'UTF-8', 'ISO-8859-1') . '" AND trashed = false ' . $_id])->getFiles();
 
                     if (count($results) == 0) {
                         $results = $instance->files->listFiles(['q' => 'name="' . ($arr_settings['file_name']) . '" AND trashed = false ' . $_id])->getFiles();
                     }
                     if (count($results) == 0) {
-                        $results = $instance->files->listFiles(['q' => 'name="' . urldecode($arr_settings['file_name']) . '" AND trashed = false ' . $_id])->getFiles();
+/*                        $results = $instance->files->listFiles(['q' => 'name="' . urldecode($arr_settings['file_name']) . '" AND trashed = false ' . $_id])->getFiles(); */
+                        $results = $instance->files->listFiles(['q' => 'name="' . mb_convert_encoding($arr_settings['file_name'], 'ISO-8859-1', 'UTF-8') . '" AND trashed = false ' . $_id])->getFiles();
                     }
 
                     if (count($results) != 0) {
@@ -1725,4 +1728,38 @@ function sc_googledrive_file_create($arr_settings,$filename,$parent_id=null,$mim
     $file->setParents([$parent_id]);
     $file = $instance->files->create($file, $options);
     return $file->id;
-}
\ No newline at end of file
+}
+
+/*
+function sc_chatgpt($key, $mens, $model="", $temperature="", $top_p="", $max_tokens=""){
+    $parms = array();
+    $parms['model']       = (!empty($model)) ? $model : 'gpt-3.5-turbo';
+    $parms['messages'][0] = array('role' => 'user', 'content' => $mens);
+    $parms['temperature'] = (!empty($temperature) && is_numeric($temperature) && $temperature < 1.1) ? $temperature : 0.7;
+    $parms['top_p']       = (!empty($top_p) && is_numeric($top_p) && $top_p < 1.1) ? $top_p : 0.8;
+    if (!empty($max_tokens) && is_numeric($max_tokens)) {
+        $parms['max_tokens'] = $max_tokens;
+    }
+
+    $api_link = curl_init('https://api.openai.com/v1/chat/completions');
+    curl_setopt($api_link, CURLOPT_CUSTOMREQUEST, 'POST');
+    curl_setopt($api_link, CURLOPT_POSTFIELDS, json_encode($parms));
+    curl_setopt($api_link, CURLOPT_RETURNTRANSFER, true);
+    curl_setopt($api_link, CURLOPT_HTTPHEADER, [
+        'Content-Type: application/json',
+        'Authorization: Bearer ' . $key,
+    ]);
+    $api_return = curl_exec($api_link);
+    curl_close($api_link);
+
+    $api_ret_decode = json_decode($api_return, true);
+    if (isset($api_ret_decode['choices'][0]['message']['content'])) {
+        return $api_ret_decode['choices'][0]['message']['content'];
+    }
+    elseif (isset($api_ret_decode['error']['message'])) {
+        return $api_ret_decode['error']['message'];
+    } else {
+        return "Communication error with OpenAI.";
+    }
+}
+*/
\ No newline at end of file
